==> json-schema-validator-0.3-sources.jar: org/eel/kitchen/jsonschema/base/Validator.java <==
/*
 * Copyright (c) 2011, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.eel.kitchen.jsonschema.base;

import org.codehaus.jackson.JsonNode;
import org.eel.kitchen.jsonschema.keyword.KeywordValidator;
import org.eel.kitchen.jsonschema.keyword.format.FormatValidator;
import org.eel.kitchen.jsonschema.main.JsonValidationFailureException;
import org.eel.kitchen.jsonschema.main.ValidationContext;
import org.eel.kitchen.jsonschema.main.ValidationReport;
import org.eel.kitchen.jsonschema.syntax.SyntaxValidator;

/**
 * Interface which all validators must implement
 *
 * @see SyntaxValidator
 * @see KeywordValidator
 * @see FormatValidator
 */
public interface Validator
{
    /**
     * Validate an instance
     *
     * @param context the validation context
     * @param instance the instance to validate
     * @return the report
     * @throws JsonValidationFailureException if the report is set to throw
     * this exception instead of collecting messages
     */
    ValidationReport validate(final ValidationContext context,
        final JsonNode instance)
        throws JsonValidationFailureException;
}

==> json-schema-validator-0.4.1-sources.jar: org/eel/kitchen/jsonschema/base/Validator.java <==
/*
 * Copyright (c) 2011, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.eel.kitchen.jsonschema.base;

import org.codehaus.jackson.JsonNode;
import org.eel.kitchen.jsonschema.keyword.KeywordValidator;
import org.eel.kitchen.jsonschema.keyword.common.format.FormatValidator;
import org.eel.kitchen.jsonschema.main.JsonValidationFailureException;
import org.eel.kitchen.jsonschema.main.ValidationContext;
import org.eel.kitchen.jsonschema.main.ValidationReport;
import org.eel.kitchen.jsonschema.syntax.SyntaxValidator;

/**
 * Interface which all validators must implement
 *
 * @see SyntaxValidator
 * @see KeywordValidator
 * @see FormatValidator
 */
public interface Validator
{
    /**
     * Validate an instance
     *
     * @param context the validation context
     * @param instance the instance to validate
     * @return the report
     * @throws JsonValidationFailureException if the report is set to throw
     * this exception instead of collecting messages
     */
    ValidationReport validate(final ValidationContext context,
        final JsonNode instance)
        throws JsonValidationFailureException;
}
